==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Shkposti");
define("_RE","Re");
define("_SUBJECT","Aihe");
define("_PRIVATEMESSAGES","Yksityisviestit");
define("_CHECKALL","Valitse kaikki");
define("_FROM","Kenelt");
define("_DATE","Piv");
define("_DONTHAVEMESSAGES","Sinulla ei ole uusia viestej");
define("_NOTREAD","ei luettu");
define("_MSGSTATUS","Viestin tila");
define("_PRIVATEMESSAGE","Yksityisviesti");
define("_INDEX","Etusivu");
define("_SENT","Lhetetty");
define("_PREVIOUSMESSAGE","Edellinen viesti");
define("_NEXTMESSAGE","Seuraava viesti");
define("_PROFILE","Profiili");
define("_ABOUTPOSTING","Tietoa lhettmisest");
define("_ALLREGCANPOST","Kaikki rekisterityneet kyttjt voivat lhett yksityisviestej");
define("_TO","Kenelle:");
define("_MESSAGEICON","Viestin ikoni");
define("_MESSAGE","Viesti");
define("_HTML","HTML");
define("_PMON","pll");
define("_PMOFF","pois");
define("_BBCODE","BBCode");
define("_WROTE","Kirjoitti");
define("_OPTIONS","Ominaisuudet");
define("_HTMLDISSABLE","l salli HTML -muotoilua tst viestist");
define("_BBCODEDISSABLE","l salli <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> tss viestiss");
define("_SMILEDISSABLE","l salli <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> tss viestiss");
define("_CANCELREPLY","Peruuta");
define("_CANCELSEND","Peruuta");
define("_CLEAR","Tyjenn");
define("_SUBMIT","Lhet");
define("_USERNOTINDB","Valitsemaasi kyttj ei lydy tietokannasta.");
define("_CHECKNAMEANDTRY","Tarkastappas nimi viel kerran.");
define("_MSGPOSTED","Viestisi on lhettetty.");
define("_RETURNTOPMSG","Voit reloadata yksityisviestisi tst.");
define("_MSGDELETED","Viestisi on tuhottu.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Shkposti");
define("_RE","Re");
define("_SUBJECT","Aihe");
define("_PRIVATEMESSAGES","Yksityisviestit");
define("_CHECKALL","Valitse kaikki");
define("_FROM","Kenelt");
define("_DATE","Piv");
define("_DONTHAVEMESSAGES","Sinulla ei ole uusia viestej");
define("_NOTREAD","ei luettu");
define("_MSGSTATUS","Viestin tila");
define("_PRIVATEMESSAGE","Yksityisviesti");
define("_INDEX","Etusivu");
define("_SENT","Lhetetty");
define("_PREVIOUSMESSAGE","Edellinen viesti");
define("_NEXTMESSAGE","Seuraava viesti");
define("_PROFILE","Profiili");
define("_ABOUTPOSTING","Tietoa lhettmisest");
define("_ALLREGCANPOST","Kaikki rekisterityneet kyttjt voivat lhett yksityisviestej");
define("_TO","Kenelle:");
define("_MESSAGEICON","Viestin ikoni");
define("_MESSAGE","Viesti");
define("_HTML","HTML");
define("_PMON","pll");
define("_PMOFF","pois");
define("_BBCODE","BBCode");
define("_WROTE","Kirjoitti");
define("_OPTIONS","Ominaisuudet");
define("_HTMLDISSABLE","l salli HTML -muotoilua tst viestist");
define("_BBCODEDISSABLE","l salli <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> tss viestiss");
define("_SMILEDISSABLE","l salli <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> tss viestiss");
define("_CANCELREPLY","Peruuta");
define("_CANCELSEND","Peruuta");
define("_CLEAR","Tyjenn");
define("_SUBMIT","Lhet");
define("_USERNOTINDB","Valitsemaasi kyttj ei lydy tietokannasta.");
define("_CHECKNAMEANDTRY","Tarkastappas nimi viel kerran.");
define("_MSGPOSTED","Viestisi on lhettetty.");
define("_RETURNTOPMSG","Voit reloadata yksityisviestisi tst.");
define("_MSGDELETED","Viestisi on tuhottu.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
